pub struct ResolvedRetryConfig {
pub upstream: ResolvedRetryLayerConfig,
pub route: ResolvedRetryLayerConfig,
pub allow_cross_station_before_first_output: bool,
pub never_on_status: String,
pub never_on_class: Vec<String>,
pub cloudflare_challenge_cooldown_secs: u64,
pub cloudflare_timeout_cooldown_secs: u64,
pub transport_cooldown_secs: u64,
pub cooldown_backoff_factor: u64,
pub cooldown_backoff_max_secs: u64,
}Fields
upstream: ResolvedRetryLayerConfigroute: ResolvedRetryLayerConfigallow_cross_station_before_first_output: boolGuarded cross-station failover before any upstream output is committed to the client.
never_on_status: Stringnever_on_class: Vec<String>cloudflare_challenge_cooldown_secs: u64cloudflare_timeout_cooldown_secs: u64transport_cooldown_secs: u64cooldown_backoff_factor: u64cooldown_backoff_max_secs: u64Trait Implementations
Sourceimpl Clone for ResolvedRetryConfig
impl Clone for ResolvedRetryConfig
Sourcefn clone(&self) -> ResolvedRetryConfig
fn clone(&self) -> ResolvedRetryConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResolvedRetryConfig
impl Debug for ResolvedRetryConfig
Sourceimpl<'de> Deserialize<'de> for ResolvedRetryConfig
impl<'de> Deserialize<'de> for ResolvedRetryConfig
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ResolvedRetryConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ResolvedRetryConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ResolvedRetryConfig
impl PartialEq for ResolvedRetryConfig
Sourcefn eq(&self, other: &ResolvedRetryConfig) -> bool
fn eq(&self, other: &ResolvedRetryConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ResolvedRetryConfig
impl Serialize for ResolvedRetryConfig
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for ResolvedRetryConfig
impl StructuralPartialEq for ResolvedRetryConfig